Bibliography
============

..
  Using Zotero "export bibliography" feature to clipboard, using Nature style. Index labels are created manually.

.. [Bec15] Becker, G. T. The Gap Between Promise and Reality: On the Insecurity of XOR Arbiter PUFs. in Cryptographic
    Hardware and Embedded Systems -- CHES 2015 (eds. Güneysu, T. & Handschuh, H.) 535–555 (Springer Berlin Heidelberg,
    2015).
.. [DV13] Delvaux, J. & Verbauwhede, I. Side channel modeling attacks on 65nm arbiter PUFs exploiting CMOS device noise.
    in Hardware-Oriented Security and Trust (HOST), 2013 IEEE International Symposium on 137–142 (IEEE, 2013).
.. [GCvDD02] Gassend, B., Clarke, D., van Dijk, M. & Devadas, S. Silicon Physical Random Functions. in Proceedings of
    the 9th ACM Conference on Computer and Communications Security 148–160 (ACM, 2002). doi:10.1145/586110.586132.
.. [MKP08] Majzoobi, M., Koushanfar, F. & Potkonjak, M. Lightweight Secure PUFs. in Proceedings of the 2008 IEEE/ACM
    International Conference on Computer-Aided Design 670–673 (IEEE Press, 2008).
.. [NSJM19] Nguyen, P. H. et al. The Interpose PUF: Secure PUF Design against State-of-the-art Machine Learning Attacks.
    IACR Transactions on Cryptographic Hardware and Embedded Systems 243–290 (2019) doi:10.13154/tches.v2019.i4.243-290.
.. [RSSD10] Rührmair, U. et al. Modeling Attacks on Physical Unclonable Functions. in Proceedings of the 17th ACM
    Conference on Computer and Communications Security 237–249 (ACM, 2010). doi:10.1145/1866307.1866335.
.. [SD07] Suh, G. E. & Devadas, S. Physical Unclonable Functions for Device Authentication and Secret Key Generation.
    in Proceedings of the 44th Annual Design Automation Conference 9–14 (ACM, 2007). doi:10.1145/1278480.1278484.
.. [TB15] Tobisch, J. & Becker, G. T. On the scaling of machine learning attacks on PUFs with application to noise
    bifurcation. in International Workshop on Radio Frequency Identification: Security and Privacy Issues 17–31
    (Springer, 2015).
.. [WBMS19] Wisiol, N. et al. Breaking the Lightweight Secure PUF: Understanding the Relation of Input Transformations
    and Machine Learning Resistance. https://eprint.iacr.org/2019/799 (2019).
.. [WM19] Wisiol, N. & Margraf, M. Why attackers lose: design and security analysis of arbitrarily large XOR arbiter
    PUFs. J Cryptogr Eng 9, 221–230 (2019).
.. [WMPN19] Wisiol, N. et al. Splitting the Interpose PUF: A Novel Modeling Attack Strategy.
    https://eprint.iacr.org/2019/1473 (2019).
.. [WP20] Wisiol, N. & Pirnay, N. Short Paper: XOR Arbiter PUFs have Systematic Response Bias.
    https://eprint.iacr.org/2019/1091 (2019).
